@@ -186,7 +186,7 @@ def make_redirecting_plugin(login_form_path=None,
         raise ValueError(
             'must include rememberer (name of another IIdentifier plugin)')
 
-    return CookieRedirectingFormPlugin(login_form_url,
+    return CookieRedirectingFormPlugin(login_form_path,
                                    login_handler_path,
                                    logout_handler_path,
                                    rememberer_name,
