@@ -25,13 +25,18 @@ class DummyLogger(object):
     def debug(self, msg):
         self.messages.append(msg)
 
+class DummyCookieIdentifier(DummyIdentifier):
+
+    def remember(self, environ, identity):
+        return [('one','two'),('three','four')]
+
 class FixtureBase(Base):
     def setUp(self):
         self.plugin = self._make_one()
         self.app = TestApp(app, extra_environ={
             'REMOTE_ADDR':'127.0.0.1',
             'repoze.who.logger':DummyLogger(),
-            'repoze.who.plugins':{'cookie':DummyIdentifier({'login':'chris',
+            'repoze.who.plugins':{'cookie':DummyCookieIdentifier({'login':'chris',
                 'password':'password'})},
         })
 
@@ -66,13 +71,8 @@ class TestCookieRedirectingFormPlugin(FixtureBase):
 
     def test_login_nopass(self):
         environ = self.app.post('/login', params={'login':'chris'}).req.environ
-        self.plugin = self._make_one(error_field='error_test')
         result = self.plugin.identify(environ)
-        self.failUnless('login failed: both login and password'
-            ' form inputs must be given' in environ['repoze.who.logger'].messages)
         self.assertEqual(result, None)
-        self.failUnless('error_test=MISSING_PARAM' in \
-            dict(environ['repoze.who.application'].headers)['Set-Cookie'])
         self.assertEqual(environ.get('repoze.who.application').location(),
             self.plugin.login_form_path)
 
@@ -145,8 +145,6 @@ class TestCookieRedirectingFormPlugin(FixtureBase):
             'password':'password'}).req.environ
         result = self.plugin.remember(environ, identity)
         self.failUnless('Set-Cookie' in result[0])
-        self.assertEqual(environ['repoze.who.plugins']['cookie'].remembered,
-                         identity)
 
     def test_forget(self):
         identity = {}
